@@ -3,9 +3,10 @@ package JSON::Meth;
 use strict;
 use warnings;
 
-our $VERSION = '1.001004'; # VERSION
+our $VERSION = '1.001005'; # VERSION
 
 use JSON::MaybeXS;
+use 5.008001;
 use Carp;
 use Scalar::Util qw/blessed/;
 require Exporter;
@@ -22,6 +23,7 @@ use overload q{""}  => sub { $data },
 our ( $json, $j );
 $json = $j = bless sub {
     my $in = shift;
+    return undef unless defined $in;
 
     my $json_obj = JSON::MaybeXS->new(
         convert_blessed => 1,
@@ -92,7 +94,7 @@ JSON::Meth - no nonsense JSON encoding/decoding as method calls on data
     # go nuts! (outputs JSON string '["bar",{"ber":"beer"}]')
     say '{"foo":["bar",{"ber":"beer"}]}'->$j->{foo}->$j;
 
-    # event this works!! Meth? Not even once!
+    # even this works!! Meth? Not even once!
     say '["woo","hoo!"]'->$j->$j->$j->$j;
 
 =for html  </div></div>
